package
Version:
v0.0.0-...-fd6e82c
Opens a new window with list of versions in this module.
Published: May 8, 2023
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Solution struct {
TaskID int `json:"task_id"`
UserID int `json:"user_id"`
Code string `json:"solution"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.